@@ -60,8 +60,12 @@ endmacro()
 
 macro(add_library)
     set(args ${ARGV})
-    list (TRANSFORM args REPLACE IMPORTED "IMPORTED;GLOBAL")
-    message(STATUS "${args}")
+    list(FIND args IMPORTED index)
+    if (index GREATER_EQUAL 0)
+        MATH(EXPR index "${index}+1")
+        list (INSERT args ${index} GLOBAL)
+    endif()
+    message(STATUS "add_library: ${args}")
     _add_library(${args})
 endmacro()
 
@@ -69,10 +73,13 @@ add_subdirectory(".." "../build")
 
 function(get_all_libs_locations ret tgt)
     set(self_loc "")
-    get_target_property(lret ${tgt} IMPORTED_LOCATION)
-    message(STATUS "got:" ${lret} "for" ${tgt})
-    if (lret)
-        set(self_loc ${lret})
+    get_target_property(lret ${tgt} TYPE)
+    if (NOT ${lret} STREQUAL INTERFACE_LIBRARY)
+        get_target_property(lret ${tgt} IMPORTED_LOCATION)
+        message(STATUS "got:" ${lret} "for" ${tgt})
+        if (lret)
+            set(self_loc ${lret})
+        endif()
     endif()
     get_target_property(deps ${tgt} INTERFACE_LINK_LIBRARIES)
     message(STATUS "deps:" ${deps} "for" ${tgt})
